##  Step 4. Implement the Optimal Project and Execute Transformations
After careful evaluation and comparison, select the optimal scenario to implement. The advantage of working with SAP LeanIX Architecture and Road Map Planning is that you have already modeled out all possible transformations on the Application and Initiatives level. Now, you only need to press the button to execute them.
  1. Have a governance and collaboration model in place with the Project Manager in your organization to ensure that project implementation data is kept up-to-date.
  2. Upon reaching milestones or implementing transformations, simply click Execute against the corresponding Transformations. The modeled impacts and changes are seamlessly reflected in your current landscape, updating your architecture in real time.


To learn more about managing and executing Transformation, see [Transformations](https://help.sap.com/docs/leanix/ea/transformations?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to define and manage Transformations in the Initiative Fact Sheet.").
